@@ -1,5 +1,5 @@
 /*  Zutils - Utilities dealing with compressed files
-    Copyright (C) 2009-2015 Antonio Diaz Diaz.
+    Copyright (C) 2009-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ int child_status( const pid_t pid, const char * const name )
     if( tmp == -1 && errno != EINTR )
       {
       if( verbosity >= 0 )
-        std::fprintf( stderr, "%s: Error checking status of '%s': %s.\n",
+        std::fprintf( stderr, "%s: Error checking status of '%s': %s\n",
                       program_name, name, std::strerror( errno ) );
       _exit( 2 );
       }
